==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_es.js <==

lang['incoming_call']      = 'Llamado Entrante';
lang['connecting_server']  = 'Conectando al servidor, intento número ';

lang['from_queue']         = "De cola:";
lang['number']             = "Número:";
lang['name']               = "Nombre:";

lang['dial']               = 'Llamar';
lang['transfer_vmail']     = 'Transferir a Buzón';
lang['transfer_external']  = 'Transferir a Movil';
lang['attendant_transfer'] = 'Transferir';
lang['spy']                = 'Escuchar';
lang['whisper']            = 'Escuchar y Susurrar';
lang['pickup']             = "Capturar Llamado";
lang['hangup']             = 'Cortar';
lang['filter']             = 'Filtrar';

lang['enter_sec_code']     = 'Ingrese los datos de acceso';
lang['exten']              = 'Extensión:';
lang['password']           = 'Clave:';

lang['confirm_hangup']     = 'Confirmación de Corte';
lang['areyousure']         = '¿Está seguro?';
lang['yes']                = 'Si';
lang['no']                 = 'No';

lang['paused']             = 'En pausa';
lang['set_information']    = 'Poner Información';
lang['member_of']          = 'Miembro de ';
lang['not_available']      = 'El sistema no está disponible en este momento';
lang['not_connect']        = 'Imposible conectar con el servidor';
lang['one_moment']         = 'Un momento por favor';
lang['no_results']         = 'No se encontraron resultados';


lang['toggle_lock']        = 'Cerrar/Abrir Conferencia';
lang['toggle_muteall']     = 'Mudo/No mudo a todos';
lang['available']          = 'Disponible';
lang['phonebook']          = 'Contactos';
lang['toggle_mute']        = 'Alternar Mudo';
lang['kick']               = 'Echar usuario';
lang['record']             = 'Grabar llamado';
lang['presence_noti']      = 'Notificacion de presencia';

lang['queues']             = 'Colas';
lang['extensions']         = 'Extensiones';
lang['trunks']             = 'Troncales';
lang['conferences']        = 'Conferencias';
lang['other']              = 'Otro';
lang['enter_state']        = 'Ingrese Valor';
lang['parkingslots']       = 'Aparcamiento';
lang['ringgroups']         = 'Grupo de Extensiones';

lang['enter_reg_code']     = 'Ingresar Codigo de Registracion:';
lang['reg_code']     = 'Codigo Registracion:';
lang['reg_name']     = 'Nombre Registracion:';

lang['remove_member']      = 'Remover Miembro';
lang['remove_member_from'] = 'Remover de ';
lang['pause_member']       = 'Pausar Miembro';
lang['unpause_member']     = 'Despausar Miembro';
lang['add_member']         = 'Agregar a ';
lang['pickup_call']        = 'Capturar Línea';
lang['email_user']         = 'Enviar email';
lang['send_sms']           = 'Enviar SMS';
lang['message']            = 'Mensaje:';
lang['sending']            = 'Enviando...';
lang['noResponse']         = 'No hubo respuesta.';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Usuario desconectado. Guardando Nota.';
lang['me']                 = 'Yo';
lang['clearchat']          = 'Limpiar ventana';
lang['note']               = 'Nota';
lang['toggle_sound']       = 'Alternar Sonido';
lang['says']               = 'dice';

lang['agents']             = 'Agentes: %d';
lang['calls']              = 'Llamados en Espera: %d';
lang['call_connected']     = 'Conectado con';
lang['changeDisplayType']  = 'Cambiar visualización';

lang['voicemail']          = 'Correo de Voz';
lang['vmail_new']          = 'Nuevos';
lang['vmail_old']          = 'Guardados';
lang['vmail_work']         = 'Trabajo';
lang['vmail_family']       = 'Familia';
lang['vmail_friends']      = 'Amigos';
lang['vmail_number']       = 'Nro';
lang['vmail_date']         = 'Fecha';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duración';

lang['preferences']        = 'Preferencias';
lang['summary']            = 'Sumario';
lang['detailed']           = 'Detallado';

lang['inactive_line']      = 'Línea %d inactiva';
lang['inuse']              = '%d líneas en uso';

lang['vmail_count']        = 'Nuevos %d, Guardados %d';
lang['logout']             = 'Salir';

lang['NOTONLINE']          = 'Usuario desconectado';
lang['NOWONLINE']          = 'El usuario se ha conectado';

lang['prefSounds']         = 'Sonidos';
lang['prefDisplay']        = 'Presentación';

lang['labelSoundChat']     = 'Sonido de Chat';
lang['labelSoundQueue']    = 'Sonido de Cola';
lang['labelSoundRing']     = 'Sonido de llamada';

lang['labelDisplayQueue']          = 'Vista de Cola por defecto:';
lang['labelDisplayDynamicLine']    = 'Visualización de Línea dinámica:';
lang['labelDisplayNotifyDuration'] = 'Duración de notificación:';
lang['labelDisplayLanguage']       = 'Idioma:';


// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Dom", "Lun", "Mar", "Mie", "Jue", "Vie", "Sab",
		"Domingo", "Lunes", "Martes", "Miércoles", "Jueves", "Viernes", "Sábado"
	],
	monthNames: [
		"Ene", "Feb", "Mar", "Abr", "May", "Jun", "Jul", "Ago", "Sep", "Oct", "Nov", "Dic",
		"Enero", "Febrero", "Marzo", "Abril", "Mayo", "Junio", "Julio", "Agosto", "Septiembre", "Octubre", "Noviembre", "Diciembre"
	]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_es.js <==

lang['incoming_call']      = 'Llamado Entrante';
lang['connecting_server']  = 'Conectando al servidor, intento número ';

lang['from_queue']         = "De cola:";
lang['number']             = "Número:";
lang['name']               = "Nombre:";

lang['dial']               = 'Llamar';
lang['transfer_vmail']     = 'Transferir a Buzón';
lang['transfer_external']  = 'Transferir a Movil';
lang['attendant_transfer'] = 'Transferir';
lang['blind_transfer'] =     'Transferir a ciegas';
lang['spy']                = 'Escuchar';
lang['whisper']            = 'Escuchar y Susurrar';
lang['pickup']             = "Capturar Llamado";
lang['hangup']             = 'Cortar';
lang['filter']             = 'Filtrar';

lang['enter_sec_code']     = 'Ingrese los datos de acceso';
lang['exten']              = 'Extensión:';
lang['password']           = 'Clave:';

lang['confirm_hangup']     = 'Confirmación de Corte';
lang['areyousure']         = '¿Está seguro?';
lang['yes']                = 'Si';
lang['no']                 = 'No';
lang['cancel']             = 'Cancelar';
lang['accept']             = 'Aceptar';

lang['paused']             = 'En pausa';
lang['set_information']    = 'Poner Información';
lang['set_penalty']        = 'Penalidad';
lang['member_of']          = 'Miembro de ';
lang['not_available']      = 'El sistema no está disponible en este momento';
lang['not_connect']        = 'Imposible conectar con el servidor';
lang['one_moment']         = 'Un momento por favor';
lang['no_results']         = 'No se encontraron resultados';

lang['toggle_lock']        = 'Cerrar/Abrir Conferencia';
lang['toggle_muteall']     = 'Mudo/No mudo a todos';
lang['phonebook']          = 'Contactos';
lang['toggle_mute']        = 'Alternar Mudo';
lang['kick']               = 'Expulsar usuario';
lang['record']             = 'Grabar llamado';
lang['presence_noti']      = 'Notificacion de presencia';

lang['queues']             = 'Colas';
lang['extensions']         = 'Extensiones';
lang['trunks']             = 'Troncales';
lang['conferences']        = 'Conferencias';
lang['enter_state']        = 'Ingrese Valor';
lang['parkingslots']       = 'Aparcamiento';
lang['ringgroups']         = 'Grupo de Extensiones';

lang['available']          = 'Disponible';
lang['other']              = 'Otro';
lang['Do not Disturb']     = 'No Molestar';
lang['Out to lunch']       = 'Almuerzo';
lang['Break']              = 'Pausa';
lang['Meeting']            = 'Reunión';

lang['enter_reg_code']     = 'Ingresar Codigo de Registracion:';
lang['reg_code']     = 'Codigo Registracion:';
lang['reg_name']     = 'Nombre Registracion:';

lang['remove_member']      = 'Remover Miembro';
lang['remove_member_from'] = 'Remover de ';
lang['pause_member']       = 'Pausar Miembro';
lang['unpause_member']     = 'Despausar Miembro';
lang['add_member']         = 'Agregar a ';
lang['pickup_call']        = 'Capturar Línea';
lang['email_user']         = 'Enviar email';
lang['send_sms']           = 'Enviar SMS';
lang['message']            = 'Mensaje:';
lang['sending']            = 'Enviando...';
lang['noResponse']         = 'No hubo respuesta.';
lang['calls_taken']        = 'Llamadas atendidas:';
lang['penalty']            = 'Penalidad:';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Usuario desconectado. Guardando Nota.';
lang['me']                 = 'Yo';
lang['clearchat']          = 'Limpiar ventana';
lang['note']               = 'Nota';
lang['toggle_sound']       = 'Alternar Sonido';
lang['says']               = 'dice';

lang['agents']             = 'Agentes: %d';
lang['calls']              = 'Llamados en Espera: %d';
lang['call_connected']     = 'Conectado con';
lang['changeDisplayType']  = 'Cambiar visualización';

lang['voicemail']          = 'Correo de Voz';
lang['vmail_new']          = 'Nuevos';
lang['vmail_old']          = 'Guardados';
lang['vmail_work']         = 'Trabajo';
lang['vmail_family']       = 'Familia';
lang['vmail_friends']      = 'Amigos';
lang['vmail_number']       = 'Nro';
lang['vmail_date']         = 'Fecha';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duración';
lang['play']               = 'Reproducir';
lang['download']           = 'Descargar';

lang['preferences']        = 'Preferencias';
lang['summary']            = 'Sumario';
lang['detailed']           = 'Detallado';

lang['inactive_line']      = 'Línea %d inactiva';
lang['inuse']              = '%d líneas en uso';

lang['vmail_count']        = 'Nuevos %d, Guardados %d';
lang['logout']             = 'Salir';

lang['NOTONLINE']          = 'Usuario desconectado';
lang['NOWONLINE']          = 'El usuario se ha conectado';

lang['prefSounds']         = 'Sonidos';
lang['prefDisplay']        = 'Presentación';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Teléfono';

lang['labelSoundChat']     = 'Sonido de Chat';
lang['labelSoundQueue']    = 'Sonido de Cola';
lang['labelSoundRing']     = 'Sonido de llamada';

lang['labelDisplayQueue']          = 'Vista de Cola por defecto';
lang['labelDisplayDynamicLine']    = 'Visualización de Línea dinámica';
lang['labelDisplayNotifyDuration'] = 'Duración de notificación';
lang['labelDisplayLanguage']       = 'Idioma';
lang['labelAutoPopup']             = 'Popup Automático';
lang['labelAutoAnswer']            = 'Auto Responder';

lang['close']                      = 'Cerrar';
lang['recordings']                 = 'Grabaciones';
lang['cdrrecords']                 = 'Registro de Llamadas';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Dom", "Lun", "Mar", "Mie", "Jue", "Vie", "Sab",
		"Domingo", "Lunes", "Martes", "Miércoles", "Jueves", "Viernes", "Sábado"
	],
	monthNames: [
		"Ene", "Feb", "Mar", "Abr", "May", "Jun", "Jul", "Ago", "Sep", "Oct", "Nov", "Dic",
		"Enero", "Febrero", "Marzo", "Abril", "Mayo", "Junio", "Julio", "Agosto", "Septiembre", "Octubre", "Noviembre", "Diciembre"
	]
};
